#!/usr/bin/env python
# -*- coding: utf-8 -*-
from flask import render_template, request , redirect , url_for
from flask.ext.login import login_required
from onyx.core.assets import getMeteo
from onyx.core import core
import os

@core.route('/weather')
@login_required
def weather():
    return render_template('weather.html', day=getMeteo.getDay(), city=getMeteo.getCity() , imgurl=getMeteo.getImg() , lat=getMeteo.getLat(), lon=getMeteo.getLon())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from onyx.core.config import music

def launch():
	os.system("mocp -S")
	os.system("mocp -a " + music.MUSIC_REPO)
	os.system("mocp -t shuffle")

def play():
	os.system("mocp -p")

def pause():
	os.system("mocp -G")

def stop():
	os.system("mocp -x")

def next():
	os.system("mocp -f")

def previous():
	os.system("mocp -r")

def getMusic(name):
	os.system('mplayer ' + music.MUSIC_REPO  + name)

def getRing(name):
	os.system('mplayer ' + music.RING_REPO  + name)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import time


def getHour():
	return time.strftime("%H:%M")

def getDate():
	return time.strftime("%d/%m/%Y")

def getDay():
	return time.strftime("%w")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import core
from flask import render_template
from flask.ext.login import login_required


@core.route('/map')
def map():
	return render_template('map/index.html')


#!/usr/bin/env python
# -*- coding: utf-8 -*-
from flask import render_template, request , redirect , url_for
from flask.ext.login import login_required
from onyx.core import core
import os

@core.route('/tv')
@login_required
def tv():
	return render_template('tv/index.html')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import db


class Calendar(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    idAccount = db.Column(db.String(64))
    title = db.Column(db.String(64))
    start = db.Column(db.String(64))
    end = db.Column(db.String(64))
    color = db.Column(db.String(64))
    allday = db.Column(db.String(64))


    @property
    def is_active(self):
        return True

    def get_id_(self):
        try:
            return unicode(self.id)  
        except NameError:
            return str(self.id)  



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from flask import render_template, request , redirect , url_for
from flask.ext.login import login_required , current_user
from onyx.core import core
from onyx.core.models import *
from onyx.core import db
import os
import json

@core.route('/task' , methods=['GET','POST'])
@login_required
def task():
	if request.method == 'GET':
		tasks = []
		bdd = TaskModel.Task.query.filter(TaskModel.Task.idAccount.endswith(str(current_user.username)))

		for fetch in bdd:	
			e = {}
			e['id'] = fetch.id
			e['text'] = fetch.text
			tasks.coreend(e)
		return render_template('task.html' , tasks=tasks)

@core.route('/task/add' , methods=['GET','POST'])
@login_required
def addTask():
	if request.method == 'POST':
		text = request.form['content']
		task = TaskModel.Task(idAccount=str(current_user.username),text=text)
		db.session.add(task)
		db.session.commit()
		return json.dumps({'status':'success','id':task.id})

@core.route('/task/delete' , methods=['GET','POST'])
@login_required
def deleteTask():
	if request.method == 'POST':
		delete = TaskModel.Task.query.filter_by(id=request.form['id'],idAccount=str(current_user.username)).first()
		db.session.delete(delete)
		db.session.commit()
		return redirect(url_for('task'))


#!/usr/bin/env python
# encoding: utf-8
__version__ = '1.0'
import os
import sys
reload(sys)
sys.setdefaultencoding('utf-8')


from flask import Flask
from flask_sqlalchemy import SQLAlchemy
from flask_login import LoginManager , login_user , login_required
from flask import flash , request , render_template , url_for , redirect
from flask_mail import Mail, Message


template_folder = os.path.dirname(os.path.dirname(__file__)) + '/templates'
static_folder = os.path.dirname(os.path.dirname(__file__)) + '/static'


core = Flask('app', template_folder=template_folder , static_folder=static_folder)
core.config.from_object('onyx.bddconfig')
db = SQLAlchemy(core)

from controllers import *
from models import *

core.config['SECRET_KEY'] = 'onyx'


from onyx.core.assets import getAlarm
getAlarm.setAlarm()







#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import core
from flask import render_template, request
from flask.ext.login import login_required


@core.errorhandler(401)
@core.errorhandler(404)
@core.errorhandler(500)
@login_required
def erreur(error):
	return render_template('404.html', error=error.code)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import core
from flask import render_template , request
from flask.ext.login import login_required
import wikipedia



@core.route('/wiki', methods=['GET', 'POST'])
@login_required
def wiki():
    if request.method == 'GET':
    	return render_template('wiki/index.html')
    wikipedia.set_lang("fr")
    article = wikipedia.page(request.form['search'])
    return render_template('wiki/result.html', head = article.title , url = article.url , summary=wikipedia.summary(request.form['search']))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import db
from sqlalchemy.ext.hybrid import hybrid_property


class User(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    username = db.Column(db.String(64), index=True, unique=True)
    email = db.Column(db.String(120), index=True, unique=True)
    password = db.Column(db.String(128))
    buttonColor = db.Column(db.String(128))


    @property
    def is_authenticated(self):
        return True

    @property
    def is_active(self):
        return True

    @property
    def is_anonymous(self):
        return False

    def get_id(self):
        try:
            return unicode(self.id)  # python 2
        except NameError:
            return str(self.id)  # python 3

    def __repr__(self):
        return '<User %r>' % (self.username)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import core
from flask import render_template, request
from flask.ext.login import login_required , current_user


@core.route('/widget' , methods=['GET' , 'POST'])
@login_required
def widget():
	if request.method == 'GET':
		return render_template('widget.html')


#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import core , db
from flask.ext.login import login_required
from flask import render_template , redirect , request , url_for , flash
from flask import send_file
from werkzeug import secure_filename
from onyx.core.config import music
from onyx.core.models import *
import os




@core.route('/reveil' , methods=['GET','POST'])
@login_required
def reveil():
    if request.method == 'GET':
    	ring = os.listdir(music.RING_REPO)
        return render_template('alarm/index.html' , ring=ring)
    try:
    	f = request.files['ringfile']
    	if f:
    		nom = secure_filename(f.filename)
    		f.save(music.RING_REPO + nom)
    		flash('Sonnerie ajoutée avec succées !' , 'success')
    		return redirect(url_for('reveil'))
    except:
    	alarms = AlarmModel.Alarm(heure=request.form['time'] , ring=request.form['ring'] , day=str(request.form.getlist('recure')), active=int(request.form['active']))
    	db.session.add(alarms)
    	db.session.commit()
    	flash('Le réveil a bien été ajouté !' , 'success')
    	return redirect(url_for('reveil'))
    

@core.route('/reveil/delete' , methods=['GET','POST'])
@login_required
def reveildel():
	if request.method == 'GET':
		try:
		    bdd = AlarmModel.Alarm.query.all()
		    resultHeureRow = []
		    for alarms in bdd:
		    	resultHeureRow.append(alarms.heure) 
			resultHeure = resultHeureRow


			resultRingRow = []
		    for alarms in bdd:
		    	resultRingRow.append(alarms.ring) 
			resultRing = resultRingRow


			resultActiveRow = []
		    for alarms in bdd:
		    	resultActiveRow.append(alarms.active) 
			resultActive = resultActiveRow


			resultDayRow = []
		    for alarms in bdd:
		    	resultDayRow.append(alarms.day) 
			resultDay = resultDayRow


			resultIdRow = []
		    for alarms in bdd:
		    	resultIdRow.append(alarms.id) 
			resultId = resultIdRow


		    return render_template('alarm/delete.html' , heure=resultHeure , ring=resultRing , statut=resultActive , day=resultDay , id=resultId )
		except:
			return render_template('alarm/delete.html' , error="Pas de Reveil")
	

@core.route('/reveil/delete/<id_delete>')
def delete_reveil(id_delete):
	try:
		delete = AlarmModel.Alarm.query.filter_by(id=id_delete).first()
		db.session.delete(delete)
		db.session.commit()
		return redirect(url_for('reveildel'))
	except:
		return redirect(url_for('reveildel', error="Pas de Reveil avec cet ID"))

@core.route('/reveil/<ring_delete>')
def delete_ring(ring_delete):
	try:
		os.remove(os.path.join(music.RING_REPO + ring_delete))
		return redirect(url_for('reveil'))
	except:
		return redirect(url_for('reveil', error="Pas de Musique avec cet ID"))


@core.context_processor
def utility_processor():
    def formateDay(tab):
    	t = tab.replace("u"," ").replace("[","").replace("]","").replace("'","").replace("1","Lundi").replace("2","Mardi").replace("3","Mercredi").replace("4","Jeudi").replace("5","Vendredi").replace("6","Samedi").replace("0","Dimanche").replace("no","Pas de récurrence")
        return t
    return dict(formateDay=formateDay)
	
@core.context_processor
def utility_processor():
    def formateStatut(tab):
    	t = tab.replace("1","Activé").replace("0","Désactivé")
        return t
    return dict(formateStatut=formateStatut)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import requests
import json


def decodeURL(url) :
	r = requests.get(url, auth=('user', 'pass'))
	t = r.json()
	return t

def decode(jsonToRead) :
	r = jsonToRead
	reply = json.loads(r)
	return reply



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from flask import render_template, request , redirect , url_for
from flask.ext.login import login_required
from onyx.core import core
import os


@core.route('/help')
@login_required
def help():
    return render_template('help.html')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import json
import time
import threading
from onyx.core.assets import getHour
from onyx.core.assets import getSpeak
from onyx.core.assets import getMusic
from onyx.core import db
from onyx.core.models import *


def setAlarm():
	bdd = getBDD()
	getAlarm(bdd)
	#threading.Timer(60, setAlarm).start()



def getBDD():
	try:
		bdd = AlarmModel.Alarm.query.all()
		print("Obtention des Alarmes")
		return bdd
	except:
		bdd = "Erreur"
		return bdd
	

def getAlarm(bdd):
	try:
		for alarms in bdd:
			today = str(getHour.getDay())	
			if today in alarms.day:
				now = getHour.getHour()
				bddalarm = alarms.heure.replace(" :",":").replace(": ",":")
				if alarms.active == "1":
					print("Prochaine Alarme : " + bddalarm + " Active")
				else : 
					print("Prochaine Alarme : " + bddalarm + " Desactive")
				if bddalarm == now and alarms.active == "1":
					lauchAlarm(alarms.ring)
			elif "no" in alarms.day:
				now = getHour.getHour()
				bddalarm = alarms.heure.replace(" :",":").replace(": ",":")
				if alarms.active == "1":
					print("Prochaine Alarme : " + bddalarm + " Active")
				else : 
					print("Prochaine Alarme : " + bddalarm + " Desactive")
				if bddalarm == now and alarms.active == "1":
					lauchAlarm(alarms.ring)
					delete = AlarmModel.Alarm.query.filter_by(id=alarms.id).first()
					db.session.delete(delete)
					db.session.commit()
	except Exception,e: print str(e)




def lauchAlarm(ring):
	print("Lancement de l'alarme en cour...")
	getMusic.getRing(ring)
	getSpeak.speak("Bonjour il est " + time.strftime("%H") + " heure " + time.strftime("%M") + " ,On est le " + time.strftime("%d/%m") + " et " + getMeteo.getText())
	


#!/usr/bin/env python
# -*- coding: utf-8 -*-
from flask import render_template, request , redirect , url_for , jsonify
from flask.ext.login import login_required , current_user
from onyx.core import core
from onyx.core.models import *
from onyx.core import db
import os
import json
import string



@core.route('/calendar')
@login_required
def calendar():
	return render_template('calendar/view.html')

@core.route('/calendar/set' , methods=['GET','POST'])
@login_required
def setCalendar():
	if request.method == 'GET':
		events = []
		bdd = CalendarModel.Calendar.query.filter(CalendarModel.Calendar.idAccount.endswith(str(current_user.username)))

		for fetch in bdd:	
			e = {}
			e['id'] = fetch.id
			e['title'] = fetch.title
			e['start'] = fetch.start
			e['end'] = fetch.end
			e['color'] = fetch.color
			events.append(e)
		return render_template('calendar/index.html' , events=events)
	update = CalendarModel.Calendar.query.filter_by(id=request.form['id'],idAccount=str(current_user.username)).first()
	update.start = request.form['start']
	update.end = request.form['end']
	db.session.add(update)
	db.session.commit()
	return json.dumps({'status':'success'})

@core.route('/calendar/set/add' , methods=['GET','POST'])
@login_required
def addCalendar():
	if request.method == 'POST':
		color = request.form['color']
		enddate = request.form['end']
		startdate = request.form['start']
		title = request.form['title']
		calendar = CalendarModel.Calendar(idAccount=str(current_user.username),title=title , start=startdate, end=enddate ,color=color)
		db.session.add(calendar)
		db.session.commit()
		return redirect(url_for('setCalendar'))

@core.route('/calendar/set/editTitle' , methods=['GET','POST'])
@login_required
def editEventTitle():
	if request.method == 'POST':
		checked = 'delete' in request.form
		if checked == True:
			delete = CalendarModel.Calendar.query.filter_by(id=request.form['id'],idAccount=str(current_user.username)).first()
			db.session.delete(delete)
			db.session.commit()
			return redirect(url_for('setCalendar'))
		update = CalendarModel.Calendar.query.filter_by(id=request.form['id'],idAccount=str(current_user.username)).first()
		update.title = request.form['title']
		update.color = request.form['color']
		db.session.add(update)
		db.session.commit()
		return redirect(url_for('setCalendar'))

@core.context_processor
def utility_processor():
    def split(str):
        return string.split(str, " ")
    return dict(split=split)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import platform

def run():
	from onyx.core import core
	core.run('0.0.0.0', port=8080 , debug=True)

def install():
	if platform.system() == "Linux":
		#os.system("sh blabla")
		from migrate.versioning import api
		from onyx.bddconfig import SQLALCHEMY_DATABASE_URI
		from onyx.bddconfig import SQLALCHEMY_MIGRATE_REPO
		from onyx.core import db
		import os.path
		db.create_all()
		if not os.path.exists(SQLALCHEMY_MIGRATE_REPO):
		    api.create(SQLALCHEMY_MIGRATE_REPO, 'database repository')
		    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		else:
		    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO,
		                        api.version(SQLALCHEMY_MIGRATE_REPO))
	else:
		from migrate.versioning import api
		from onyx.bddconfig import SQLALCHEMY_DATABASE_URI
		from onyx.bddconfig import SQLALCHEMY_MIGRATE_REPO
		from onyx.core import db
		import os.path
		db.create_all()
		if not os.path.exists(SQLALCHEMY_MIGRATE_REPO):
		    api.create(SQLALCHEMY_MIGRATE_REPO, 'database repository')
		    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		else:
		    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO,
		                        api.version(SQLALCHEMY_MIGRATE_REPO))

def maj():
	if platform.system() == "Linux":
		os.system("sh blabla")
		import imp
		from migrate.versioning import api
		from onyx.core import db
		from bddconfig import SQLALCHEMY_DATABASE_URI
		from bddconfig import SQLALCHEMY_MIGRATE_REPO
		v = api.db_version(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		migration = SQLALCHEMY_MIGRATE_REPO + ('/versions/%03d_migration.py' % (v+1))
		tmp_module = imp.new_module('old_model')
		old_model = api.create_model(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		exec(old_model, tmp_module.__dict__)
		script = api.make_update_script_for_model(SQLALCHEMY_DATABASE_URI,
		                                          SQLALCHEMY_MIGRATE_REPO,
		                                          tmp_module.meta, db.metadata)
		open(migration, "wt").write(script)
		api.upgrade(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		v = api.db_version(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		print('New migration saved as ' + migration)
		print('Current database version: ' + str(v))
	else:
		import imp
		from migrate.versioning import api
		from onyx.core import db
		from bddconfig import SQLALCHEMY_DATABASE_URI
		from bddconfig import SQLALCHEMY_MIGRATE_REPO
		v = api.db_version(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		migration = SQLALCHEMY_MIGRATE_REPO + ('/versions/%03d_migration.py' % (v+1))
		tmp_module = imp.new_module('old_model')
		old_model = api.create_model(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		exec(old_model, tmp_module.__dict__)
		script = api.make_update_script_for_model(SQLALCHEMY_DATABASE_URI,
		                                          SQLALCHEMY_MIGRATE_REPO,
		                                          tmp_module.meta, db.metadata)
		open(migration, "wt").write(script)
		api.upgrade(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		v = api.db_version(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
		print('New migration saved as ' + migration)
		print('Current database version: ' + str(v))





#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import core
from onyx.core.assets import getMusic
from flask import render_template , redirect , url_for, request ,flash
from flask import send_file
from werkzeug import secure_filename
from flask.ext.login import login_required
import os


@core.route('/music', methods = ['GET', 'POST'])
@login_required
def music():
    if request.method == 'GET':
        music = os.listdir(os.path.dirname(os.path.dirname(os.path.dirname(__file__))) + '/static/music')
        return render_template('music/index.html' , music=music)
    f = request.files['musicfile']
    if f:
        nom = secure_filename(f.filename)
        f.save(os.path.dirname(os.path.dirname(os.path.dirname(__file__))) + '/static/music/' + nom)
        flash('La musique a bien été enregistrée' , 'success')
        return redirect(url_for('music'))

@core.route('/music/play')
@login_required
def play():
    getMusic.launch()
    getMusic.play()
    return redirect(url_for('music'))

@core.route('/music/pause')
@login_required
def pause():
    getMusic.pause()
    return redirect(url_for('music'))

@core.route('/music/stop')
@login_required
def stop():
    getMusic.stop()
    return redirect(url_for('music'))


@core.route('/music/next')
@login_required
def next():
    getMusic.next()
    return redirect(url_for('music'))


@core.route('/music/previous')
@login_required
def previous():
    getMusic.previous()
    return redirect(url_for('music'))


@core.route('/music/<music_delete>')
def delete_music(music_delete):
    try:
        os.remove(os.path.join(os.path.dirname(os.path.dirname(os.path.dirname(__file__))) + '/static/music/' + music_delete))
        return redirect(url_for('music'))
    except:
        return redirect(url_for('music', error="Pas de Musique avec cet ID"))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json
from onyx.core import core
from onyx.core.assets import getAvatar
from flask import render_template, request , jsonify
from flask.ext.login import login_required , current_user



@core.route('/')
@login_required
def index():	
    return render_template('index.html')


@core.context_processor
def Avatar():
    urlAvatar = getAvatar.getAvatar()
    return dict(urlAvatar=urlAvatar)


@core.context_processor
def ButtonColor():
	try:
		buttonColor = current_user.buttonColor
	except:
		buttonColor = ""
	return dict(buttonColor=buttonColor)

@core.context_processor
def currentUser():
	try:
		currentUser = current_user.username
	except:
		currentUser = "User"
	return dict(currentUser=currentUser)

@core.context_processor
def currentEmail():
	try:
		currentEmail = current_user.email
	except:
		currentEmail = "Email"
	return dict(currentEmail=currentEmail)

@core.context_processor
def currentID():
	try:
		currentID = current_user.id
	except:
		currentID = "ID"
	return dict(currentID=currentID)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os

MUSIC_REPO = os.path.dirname(os.path.dirname(os.path.dirname(__file__))) + '/static/music/'
RING_REPO = os.path.dirname(os.path.dirname(os.path.dirname(__file__))) + '/static/ringstone/'





#!/usr/bin/env python
# -*- coding: utf-8 -*-
from flask import render_template, request , redirect , url_for
from flask.ext.login import login_required
from onyx.core import core



@core.route('/store')
@login_required
def store():
    return render_template('store/index.html')


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from onyx.core.assets import decodeJSON
from onyx.core.assets import getGeolocalisation


def getText() :
	geoloc = getGeolocalisation.get()
	result = decodeJSON.decodeURL("http://api.openweathermap.org/data/2.5/forecast/daily?lat=" + str(geoloc["lat"]) + "&lon=" + str(geoloc["lon"]) + "&cnt=14&mode=json&units=metric&lang=fr&appid=184b6f0b48a04263c59b93aee56c4d69")
	return "Il fait " + str(round(result["list"][0]["temp"]["day"])) + " degrès à " + str(result["city"]["name"]) + " !"

def get():
	geoloc = getGeolocalisation.get()
	result = decodeJSON.decodeURL("http://api.openweathermap.org/data/2.5/forecast/daily?lat=" + str(geoloc["lat"]) + "&lon=" + str(geoloc["lon"]) + "&cnt=14&mode=json&units=metric&lang=fr&appid=184b6f0b48a04263c59b93aee56c4d69")
	return result

def getDay():
	geoloc = getGeolocalisation.get()
	result = decodeJSON.decodeURL("http://api.openweathermap.org/data/2.5/forecast/daily?lat=" + str(geoloc["lat"]) + "&lon=" + str(geoloc["lon"]) + "&cnt=14&mode=json&units=metric&lang=fr&appid=184b6f0b48a04263c59b93aee56c4d69")
	return str(round(result["list"][0]["temp"]["day"]))

def getCity():
	geoloc = getGeolocalisation.get()
	result = decodeJSON.decodeURL("http://api.openweathermap.org/data/2.5/forecast/daily?lat=" + str(geoloc["lat"]) + "&lon=" + str(geoloc["lon"]) + "&cnt=14&mode=json&units=metric&lang=fr&appid=184b6f0b48a04263c59b93aee56c4d69")
	return str(result["city"]["name"])

def getImg():
	geoloc = getGeolocalisation.get()
	result = decodeJSON.decodeURL("http://api.openweathermap.org/data/2.5/forecast/daily?lat=" + str(geoloc["lat"]) + "&lon=" + str(geoloc["lon"]) + "&cnt=14&mode=json&units=metric&lang=fr&appid=184b6f0b48a04263c59b93aee56c4d69")
	if result["list"][0]["weather"][0]["main"] == 'Rain':
		url = "rain.png" 
	elif result["list"][0]["weather"][0]["main"] == 'Clear':
		url = "clear.png"
	elif result["list"][0]["weather"][0]["main"] == 'Thunderstorm':
		url = "pikacloud.png"
	elif result["list"][0]["weather"][0]["main"] == 'Drizzle':
		url = "rain.png"
	elif result["list"][0]["weather"][0]["main"] == 'Snow':
		url = "snowing.png"
	elif result["list"][0]["weather"][0]["main"] == 'Atmosphere':
		url = "cloud1.png"
	elif result["list"][0]["weather"][0]["main"] == 'Clouds':
		url = "cloud.png"
	elif result["list"][0]["weather"][0]["main"] == 'Extreme':
		url = "windy.png"
	else:
		url = ""
	

	return url

def getLat():
	geoloc = getGeolocalisation.get()
	return str(geoloc["lat"])

def getLon():
	geoloc = getGeolocalisation.get()
	return str(geoloc["lon"])




#!/usr/bin/env python
# -*- coding: utf-8 -*-
import hashlib
from onyx.core import db
from onyx.core.models import *
from flask import session
from flask.ext.login import current_user


def getAvatar():
	try:
		user = UsersModel.User.query.filter_by(id=current_user.id).first()
		email = str(user.email)
		default = "http://www.gravatar.com/avatar"
		size = 60
		url = "http://www.gravatar.com/avatar/" + hashlib.md5(email.lower()).hexdigest() + "?d=" + default + "&s=" +str(size)
		return url
	except:
		url = "http://www.gravatar.com/avatar"
		return url


#! /usr/bin/env python

import sys

from setuptools import setup , find_packages


setup(name="onyxproject",
      description="Intelligent Dashboard for Raspberry pi",
      long_description=open("README.rst").read(),
      version='0.1',
      packages=find_packages(),
      include_package_data=True,
      url="https://github.com/OnyxProject/Onyx",
      maintainer=("Aituglo"),
      maintainer_email="project@onyxlabs.fr",
      classifiers=[
          "Development Status :: 5 - Production/Stable",
          "Environment :: Web Environment",
          "Intended Audience :: Developers",
          "Intended Audience :: System Administrators",
          "Operating System :: Microsoft :: Windows",
          "Operating System :: OS Independent",
          "Programming Language :: Python :: 2.7",
          "Topic :: Software Development :: Build Tools",
          "Topic :: System :: Software Distribution"],
      zip_safe=True,
      entry_points={
          'console_scripts': ['onyx_start=onyx:run','onyx_install=onyx:install','onyx_maj=onyx:maj']
      },
      install_requires=['Flask==0.10.1','Flask-WTF==0.8.3','Flask-sqlalchemy','requests','beautifulsoup4','Flask-Menu','Flask-Login','SQLAlchemy-migrate','flask_bcrypt','flask-Mail','blinker','wikipedia','markupsafe'],
      options={
          'bdist_wheel': {'universal': True},
      },
      platforms=['any'],
      )



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import core
from flask.ext.login import LoginManager , login_user , login_required , current_user , login_user , logout_user
from flask import request , render_template , redirect , url_for , flash , session
from onyx.core.models import *
from onyx.core import db
import hashlib


login_manager = LoginManager()
login_manager.init_app(core)

login_manager.login_view = 'hello'



@login_manager.user_loader
def load_user(id):
    return UsersModel.User.query.get(int(id))

@core.route('/register' , methods=['GET','POST'])
def register():
    if request.method == 'GET':
        return render_template('account/register.html')
    try:
        if request.form['password'] == request.form['verifpassword']:
            hashpass = hashlib.sha1(request.form['password']).hexdigest()
            user = UsersModel.User(username=request.form['username'] , password=hashpass, email=request.form['email'])
            db.session.add(user)
            db.session.commit()
            flash('Compte ajouté avec succés' , 'success')
            return redirect(url_for('hello'))
        else:
            flash('Les mots de passe de sont pas les même !' , 'error')
            return redirect(url_for('register'))
    except:
        flash('une erreur est survenu !' , 'error')
        return redirect(url_for('hello'))

@core.route('/hello')
def hello():
    login_manager.login_view = 'hello'
    return render_template('account/hello.html')
 

@core.route('/login',methods=['GET','POST'])
def login():
    if request.method == 'GET':
        return render_template('account/login.html')
    username = request.form['username']
    password = request.form['password']
    registered_user = UsersModel.User.query.filter_by(username=username,password=hashlib.sha1(password).hexdigest()).first()
    if registered_user is None:
        return redirect(url_for('login'))
    login_user(registered_user)
    registered_user.authenticated = True
    flash('Vous vous êtes connecté avec succés', 'success')
    return redirect(request.args.get('next') or url_for('index'))



@core.route('/account/delete' , methods=['GET','POST'])
@login_required
def accountdel():
    if request.method == 'GET':
        try:
            bdd = UsersModel.User.query.all()
            resultUsername = []
            for myusers in bdd:
                resultUsername.append(myusers.username) 
            resultUser = resultUsername

            resultEmailRow = []
            for myusers in bdd:
                resultEmailRow.append(myusers.email) 
            resultEmail = resultEmailRow

            resultIdRow = []
            for myusers in bdd:
                resultIdRow.append(myusers.id) 
            resultId = resultIdRow


            return render_template('account/delete.html' , username=resultUser , email=resultEmail , id=resultId )
        except:
            return render_template('account/delete.html' , error="Pas de comptes")


@core.route('/account/delete/<id_delete>')
def delete_account(id_delete):
    try:
        delete = UsersModel.User.query.filter_by(id=id_delete).first()
        db.session.delete(delete)
        db.session.commit()
        deleteCalendar = CalendarModel.Calendar.query.filter(CalendarModel.Calendar.idAccount.endswith(str(id_delete)))
        db.session.delete(deleteCalendar)
        db.session.commit()
        return redirect(url_for('accountdel'))
    except:
        return redirect(url_for('accountdel', error="Pas de comptes avec cet ID"))


@core.route('/account/manage' , methods=['GET','POST'])
@login_required
def accountManage():
    if request.method == 'GET':
        bdd = UsersModel.User.query.filter_by(username=current_user.username).first()
        buttonColor = bdd.buttonColor
        return render_template('account/manage.html' ,buttonColor=buttonColor )
    try:
        user = UsersModel.User.query.filter_by(username=current_user.username).first()
        if hashlib.sha1(request.form['lastpassword']).hexdigest() == user.password:
            if not request.form['color']:
                user.buttonColor = current_user.buttonColor
            else:     
                user.buttonColor = request.form['color']
            if not request.form['username']:
                user.username = current_user.username
            else:
                user.username = request.form['username']
            if not request.form['email']:
                user.email = current_user.email
            else:
                user.email = request.form['email']
            if not request.form['password']:
                user.password = current_user.password
            else:
                user.password = hashlib.sha1(request.form['password']).hexdigest()
            db.session.add(user)
            db.session.commit()
            flash('Compte modifié avec succés' , 'success')
            return redirect(url_for('accountManage'))
        else:
            flash('Les mots de passe de sont pas les même !' , 'error')
            return redirect(url_for('accountManage'))
    except:
        return redirect(url_for('accountManage'))


@core.route('/lock' , methods=['GET','POST'])
def lock():
    if request.method == 'GET':
        login_manager.login_view = 'lock'
        logout_user()
        return render_template('account/lock.html')
    username = current_user.username
    password = request.form['password']
    registered_user = UsersModel.User.query.filter_by(username=username,password=hashlib.sha1(password).hexdigest()).first()
    if registered_user is None:
        return redirect(url_for('lock'))
    login_user(registered_user)
    registered_user.authenticated = True
    return redirect(request.args.get('next') or url_for('index'))

@core.route('/logout' , methods=['GET','POST'])
def logout():
    login_manager.login_view = 'hello'
    logout_user()
    flash('Vous êtes déconnecté' , 'info')
    return redirect(url_for('hello'))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
from onyx.core import core
from flask import render_template
from flask.ext.login import login_required

@core.route('/options')
@login_required
def options():
    return render_template('options/index.html')


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import json
from onyx.core.assets import decodeJSON
from bs4 import BeautifulSoup
import urllib


def getMetro(line , station , direction) : 
	html = urllib.urlopen('http://www.ratp.fr/horaires/fr/ratp/metro/prochains_passages/PP/' + station + '/' + line + '/' + direction).read()
	ratp = BeautifulSoup(html)
	jsonCreate = json.dumps({"line" : ratp.findAll('img')[24].get('alt'), "station" : ratp.findAll('span')[21].string,"direction" : ratp.findAll('td')[1].string,"name1": ratp.findAll('td')[1].string , "horaire1": ratp.findAll('td')[2].string , "name2": ratp.findAll('td')[3].string , "horaire2": ratp.findAll('td')[4].string , "name3": ratp.findAll('td')[5].string , "horaire3": ratp.findAll('td')[6].string , "name4": ratp.findAll('td')[7].string , "horaire4": ratp.findAll('td')[8].string})
	result = decodeJSON.decode(jsonCreate)
	return result

def getMetroURL(url) : 
	html = urllib.urlopen(url).read()
	ratp = BeautifulSoup(html)
	jsonCreate = json.dumps({"line" : ratp.findAll('img')[24].get('alt'), "station" : ratp.findAll('span')[21].string,"direction" : ratp.findAll('td')[1].string,"name1": ratp.findAll('td')[1].string , "horaire1": ratp.findAll('td')[2].string , "name2": ratp.findAll('td')[3].string , "horaire2": ratp.findAll('td')[4].string , "name3": ratp.findAll('td')[5].string , "horaire3": ratp.findAll('td')[6].string , "name4": ratp.findAll('td')[7].string , "horaire4": ratp.findAll('td')[8].string})
	result = decodeJSON.decode(jsonCreate)
	return result

def getRer(line , station , direction) : 
	html = urllib.urlopen('http://www.ratp.fr/horaires/fr/ratp/rer/prochains_passages/' + line + '/' + station + '/' + direction).read()
	ratp = BeautifulSoup(html)
	jsonCreate = json.dumps({"line" : ratp.findAll('img')[24].get('alt'), "station" : ratp.findAll('span')[21].string,"direction" : ratp.findAll('td')[1].string,"name1": ratp.findAll('td')[1].string , "horaire1": ratp.findAll('td')[2].string , "name2": ratp.findAll('td')[3].string , "horaire2": ratp.findAll('td')[4].string , "name3": ratp.findAll('td')[5].string , "horaire3": ratp.findAll('td')[6].string , "name4": ratp.findAll('td')[7].string , "horaire4": ratp.findAll('td')[8].string})
	result = decodeJSON.decode(jsonCreate)
	return result

def getRerURL(url) : 
	html = urllib.urlopen(url).read()
	ratp = BeautifulSoup(html)
	jsonCreate = json.dumps({"line" : ratp.findAll('img')[24].get('alt'), "station" : ratp.findAll('span')[21].string,"direction" : ratp.findAll('td')[1].string,"name1": ratp.findAll('td')[1].string , "horaire1": ratp.findAll('td')[2].string , "name2": ratp.findAll('td')[3].string , "horaire2": ratp.findAll('td')[4].string , "name3": ratp.findAll('td')[5].string , "horaire3": ratp.findAll('td')[6].string , "name4": ratp.findAll('td')[7].string , "horaire4": ratp.findAll('td')[8].string})
	result = decodeJSON.decode(jsonCreate)
	return result


import os
basedir = os.path.abspath(os.path.dirname(__file__))



SQLALCHEMY_DATABASE_URI = 'sqlite:///' + os.path.join(os.path.join(basedir, 'db') , 'app.db')
SQLALCHEMY_MIGRATE_REPO = os.path.join(os.path.join(basedir, 'db') , 'db_repository')
SQLALCHEMY_TRACK_MODIFICATIONS = True



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json
import time
import requests
from onyx.core import core
from onyx.core.assets import getRatpSchedule
from flask import render_template, request , redirect

 
@core.route('/transport')
def transport():
    return render_template('transport/index.html')

@core.route('/transport/rer', methods=['GET', 'POST'])
def rer():
    if request.method == 'POST':
        return redirect('/transport/rer/'+request.form['rerline'])
    return render_template('transport/ratp/rer/index.html')

@core.route('/transport/rer/A', methods=['GET', 'POST'])
def RERA():
    if request.method == 'POST':
        rer = "RA"
        station = request.form['rerstation']
        direction = request.form['rerdirection']
        return render_template('transport/ratp/rer/result.html', result=getRatpSchedule.getRer(rer, station, direction))
    return render_template('transport/ratp/rer/RER A.html')

@core.route('/transport/rer/B', methods=['GET', 'POST'])
def RERB():
    if request.method == 'POST':
        rer = "RB"
        station = request.form['rerstation']
        direction = request.form['rerdirection']
        return render_template('transport/ratp/rer/result.html', result=getRatpSchedule.getRer(rer, station, direction))
    return render_template('transport/ratp/rer/RER B.html')







@core.route('/transport/metro', methods=['GET', 'POST'])
def metro():
    if request.method == 'POST':
        return redirect('/transport/metro/'+request.form['metroline'])
    return render_template('transport/ratp/metro/index.html')

@core.route('/transport/metro/M1', methods=['GET', 'POST'])
def M1():
    if request.method == 'POST':
        line = "1"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        checkbox = request.form.getlist('remember')
        return render_template('transport/ratp/metro/result.html' ,result=getRatpSchedule.getMetro(line, station, direction) , test=checkbox)
    return render_template('transport/ratp/metro/M1.html')

@core.route('/transport/metro/M2', methods=['GET', 'POST'])
def M2():
    if request.method == 'POST':
        line = "2"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M2.html')

@core.route('/transport/metro/M3', methods=['GET', 'POST'])
def M3():
    if request.method == 'POST':
        line = "3"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M3.html')

@core.route('/transport/metro/M3b', methods=['GET', 'POST'])
def M3b():
    if request.method == 'POST':
        line = "3b"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M3b.html')

@core.route('/transport/metro/M4', methods=['GET', 'POST'])
def M4():
    if request.method == 'POST':
        line = "4"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M4.html')

@core.route('/transport/metro/M5', methods=['GET', 'POST'])
def M5():
    if request.method == 'POST':
        line = "5"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M5.html')

@core.route('/transport/metro/M6', methods=['GET', 'POST'])
def M6():
    if request.method == 'POST':
        line = "6"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M6.html')

@core.route('/transport/metro/M7', methods=['GET', 'POST'])
def M7():
    if request.method == 'POST':
        line = "7"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M7.html')

@core.route('/transport/metro/M7b', methods=['GET', 'POST'])
def M7b():
    if request.method == 'POST':
        line = "7b"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M7b.html')

@core.route('/transport/metro/M8', methods=['GET', 'POST'])
def M8():
    if request.method == 'POST':
        line = "8"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M8.html')

@core.route('/transport/metro/M9', methods=['GET', 'POST'])
def M9():
    if request.method == 'POST':
        line = "9"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M9.html')

@core.route('/transport/metro/M10', methods=['GET', 'POST'])
def M10():
    if request.method == 'POST':
        line = "10"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M10.html')

@core.route('/transport/metro/M11', methods=['GET', 'POST'])
def M11():
    if request.method == 'POST':
        line = "11"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M11.html')

@core.route('/transport/metro/M12', methods=['GET', 'POST'])
def M12():
    if request.method == 'POST':
        line = "12"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M12.html')

@core.route('/transport/metro/M13', methods=['GET', 'POST'])
def M13():
    if request.method == 'POST':
        line = "13"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M13.html')

@core.route('/transport/metro/M14', methods=['GET', 'POST'])
def M14():
    if request.method == 'POST':
        line = "14"
        station = request.form['metrostation']
        direction = request.form['metrodirection']
        return render_template('transport/ratp/metro/result.html', result=getRatpSchedule.getMetro(line, station, direction))
    return render_template('transport/ratp/metro/M14.html')

